| Title: | Item Response Theory Reliability |
|---|---|
| Description: | Estimation of reliability coefficients for ability estimates and sum scores from item response theory models as defined in Cheng, Y., Yuan, K.-H. and Liu, C. (2012) <doi:10.1177/0013164411407315> and Kim, S. and Feldt, L. S. (2010) <doi:10.1007/s12564-009-9062-8>. The package supports the 3-PL and generalized partial credit models and includes estimates of the standard errors of the reliability coefficient estimators, derived in Andersson, B. and Xin, T. (2018) <doi:10.1177/0013164417713570>. |
| Authors: | Bjorn Andersson |
| Maintainer: | Bjorn Andersson <[email protected]> |
| License: | GPL-2 | GPL-3 |
| Version: | 0.1-1 |
| Built: | 2026-05-24 08:37:07 UTC |
| Source: | https://github.com/cran/irtreliability |
A function to estimate marginal and test reliability from estimated item response theory models.
irtreliability(input, model, cats, relcoef = "trc", nquad = 49, SE = TRUE)irtreliability(input, model, cats, relcoef = "trc", nquad = 49, SE = TRUE)
input |
An object of class SingleGroupClass from package mirt. |
model |
A character vector indicating the item response theory model used, options are "GPCM" and "3-PL". |
cats |
A numeric vector indicating the number of possible categories for each item. |
relcoef |
A character vector indicting which reliability coefficients to calculate, options are "mrc" for the marginal reliability coefficient and "trc" for the test reliability coefficient. |
nquad |
The number of Gauss-Hermite quadrature points to be used. |
SE |
A logical vector denoting whether the standard errors for the reliability coefficient estimates should be calculated. |
An S4 object of class 'relout' which includes the following slots
est |
The estimated coefficient. |
cov |
The estimated variance. |
pder |
The partial derivatives of the coefficient with respect to the item parameters. |
type |
The type of coefficient. |
Andersson, B. and Xin, T. (2018). Large Sample Confidence Intervals for Item Response Theory Reliability Coefficients. Educational and Psychological Measurement, 78, 32-45.
Cheng, Y., Yuan, K.-H. and Liu, C. (2012). Comparison of reliability measures under factor analysis and item response theory. Educational and Psychological Measurement, 72, 52-67.
Green, B. F., Bock, R. D., Humphreys, L. G., Linn, R. L. and Reckase, M. D. (1984). Technical guidelines for assessing computerized adaptive tests. Journal of Educational Measurement, 21, 347-360.
Kim, S. (2012). A note on the reliability coefficients for item response model-based ability estimates. Psychometrika, 77, 153-162.
Kim, S. and Feldt, L. S. (2010). The estimation of the IRT reliability coefficient and its lower and upper bounds, with comparisons to CTT reliability statistics. Asia Pacific Education Review, 11, 179-188.
#Generate 2-PL data set.seed(14) akX <- runif(15, 0.5, 2) bkX <- rnorm(15) data2pl <- matrix(0, nrow = 1000, ncol = 15) for(i in 1:1000){ ability <- rnorm(1) data2pl[i,1:15] <- (1 / (1 + exp(-akX *(ability - bkX)))) > runif(15) } #Estimate the 2-PL IRT model with package mirt library(mirt) sim2pl <- mirt(data.frame(data2pl), 1, "gpcm", SE = TRUE) mrc2pl <- irtreliability(sim2pl, "GPCM", rep(2, 15), relcoef = "mrc") trc2pl <- irtreliability(sim2pl, "GPCM", rep(2, 15))#Generate 2-PL data set.seed(14) akX <- runif(15, 0.5, 2) bkX <- rnorm(15) data2pl <- matrix(0, nrow = 1000, ncol = 15) for(i in 1:1000){ ability <- rnorm(1) data2pl[i,1:15] <- (1 / (1 + exp(-akX *(ability - bkX)))) > runif(15) } #Estimate the 2-PL IRT model with package mirt library(mirt) sim2pl <- mirt(data.frame(data2pl), 1, "gpcm", SE = TRUE) mrc2pl <- irtreliability(sim2pl, "GPCM", rep(2, 15), relcoef = "mrc") trc2pl <- irtreliability(sim2pl, "GPCM", rep(2, 15))
Estimates of reliability coefficients and coefficients related to the reliability.
Objects can be created by calls of the form new("keout", ...).
The estimated coefficient.
The estimated variance.
The partial derivatives of the coefficient with respect to the item parameters.
The type of coefficient.
showClass("relout")showClass("relout")